Bitcoin Embed
A library for embedding arbitrary data and TLV-encoded messages in Bitcoin transactions. Supports OP_RETURN outputs, witness script envelopes, and taproot annexes.
See README.md for detailed documentation.
Modules
Structs
- Embedding
- A struct containing data and its location in a transaction
- Embedding
Id - A unique identifier for an embedding
Enums
- Embedding
IdError - Error types for decoding an EmbeddingId
- Embedding
Location - The location where data exists in a transaction
- Embedding
Type - The type of location where data may exist in a transaction
- Script
Type - The script type used by an envelope
Constants
- TAPROOT_
ANNEX_ DATA_ TAG - The initial byte in a data-carrying taproot annex