pub enum EmbeddingLocation {
OpReturn {
output: usize,
},
TaprootAnnex {
input: usize,
},
WitnessEnvelope {
input: usize,
index: usize,
pushes: Vec<usize>,
script_type: ScriptType,
},
}Expand description
The location where data exists in a transaction
Variants
OpReturn
An OP_RETURN with the output index
TaprootAnnex
A taproot annex with the input index
WitnessEnvelope
An OP_FALSE OP_IF <DATA> OP_ENDIF envelope with the input index, envelope index, and data push sizes
Witness envelopes are found in the following contexts:
- TapScript leaf scripts in Taproot script path spends (P2TR)
- Witness scripts in P2WSH spends with at least 2 witness stack elements
Implementations
Sourceimpl EmbeddingLocation
impl EmbeddingLocation
Sourcepub fn to_type(&self) -> EmbeddingType
pub fn to_type(&self) -> EmbeddingType
Returns the embedding type