Module envelope

Module envelope 

Script Envelope Encoding

Functions

append_bytes_to_builder
Adds bytes to a Bitcoin script using the envelope pattern (OP_FALSE OP_IF … OP_ENDIF)
append_to_builder
Adds envelope to a Bitcoin script using the envelope pattern (OP_FALSE OP_IF … OP_ENDIF)
from_script
Extracts envelopes from Bitcoin script

Type Aliases

Envelope
An Envelope represents a series of data pushes