Script Envelope Encoding
Functions
- append_
bytes_ to_ builder - Adds bytes to a Bitcoin script using the envelope pattern (OP_FALSE OP_IF … OP_ENDIF)
- append_
to_ builder - Adds envelope to a Bitcoin script using the envelope pattern (OP_FALSE OP_IF … OP_ENDIF)
- from_
script - Extracts envelopes from Bitcoin script
Type Aliases
- Envelope
- An Envelope represents a series of data pushes